@@ -1,6 +1,6 @@
 package Text::VisualPrintf;
 
-our $VERSION = "4.01";
+our $VERSION = "4.02";
 
 use v5.14;
 use warnings;
@@ -18,14 +18,17 @@ sub vsprintf { &sprintf(@_) }
 use Text::VisualWidth::PP;
 our $IS_TARGET = qr/[\e\b\P{ASCII}]/;
 our $VISUAL_WIDTH = \&Text::VisualWidth::PP::width;
+our $REORDER //= 0;
 
 sub sprintf {
     my($format, @args) = @_;
     my $conceal = Text::Conceal->new(
-	except => $format,
-	test   => $IS_TARGET,
-	length => $VISUAL_WIDTH,
-	max    => int @args,
+	except    => $format,
+	test      => $IS_TARGET,
+	length    => $VISUAL_WIDTH,
+	max       => int @args,
+	ordered   => ! $REORDER,
+	duplicate => !!$REORDER,
 	);
     $conceal->encode(@args) if $conceal;
     my $s = CORE::sprintf $format, @args;
@@ -60,12 +63,16 @@ Text::VisualPrintf - printf family functions to handle Non-ASCII characters
 
 =head1 VERSION
 
-Version 4.01
+Version 4.02
 
 =head1 DESCRIPTION
 
-Text::VisualPrintf is a almost-printf-compatible library with a
-capability of handling multi-byte wide characters properly.
+B<Text::VisualPrintf> is a almost-printf-compatible library with a
+capability of handling:
+
+    - Multi-byte wide characters
+    - Combining characters
+    - Backspaces
 
 When the given string is truncated by the maximum precision, space
 character is padded if the wide character does not fit to the remained
@@ -95,6 +102,17 @@ to work with FILEHANDLE and printf.
 
 =over 4
 
+=item $REORDER
+
+The original C<printf> function has the ability to specify the
+arguments to be targeted by the position specifier, but by default
+this module assumes that the arguments will appear in the given order,
+so you will not get the expected result. If you wish to use it, set
+the package variable C<$REORDER> to 1.
+
+By doing so, the order in which arguments appear can be changed and
+the same argument can be processed even if it appears more than once.
+
 =item $VISUAL_WIDTH
 
 Hold a function reference to calculate visual width of given string.
@@ -122,11 +140,11 @@ one.
 =head1 SEE ALSO
 
 L<Text::VisualPrintf>, L<Text::VisualPrintf::IO>,
-L<https://github.com/kaz-utashiro/Text-VisualPrintf>
+L<https://github.com/tecolicom/Text-VisualPrintf>
 
-L<Text::Conceal>, L<https://github.com/kaz-utashiro/Text-Conceal>
+L<Text::Conceal>, L<https://github.com/tecolicom/Text-Conceal>
 
-L<Text::ANSI::Printf>, L<https://github.com/kaz-utashiro/Text-ANSI-Printf>
+L<Text::ANSI::Printf>, L<https://github.com/tecolicom/Text-ANSI-Printf>
 
 =head1 AUTHOR
 
@@ -134,7 +152,7 @@ Kazumasa Utashiro
 
 =head1 LICENSE
 
-Copyright 2011-2020 Kazumasa Utashiro.
+Copyright 2011-2023 Kazumasa Utashiro.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
